#ifndef _NG_IRLAP_H_
#define _NG_IRLAP_H_

/* Type name and cookie */
#define	NG_IRLAP_NODE_TYPE	"irlap"
#define NGM_IRLAP_COOKIE	959340587

/* Hook names */
#define NG_IRLAP_HOOK_DOWN	"down"	/* To lower layer (ie Ir device) */
#define NG_IRLAP_HOOK_UP	"up"	/* To upper layer (ie IrLMP) */

/* Defaults */
#define	NG_IRLAP_DEFAULT_RATE		0x0200
#define	NG_IRLAP_DEFAULT_MAXTURN	0x01
#define	NG_IRLAP_DEFAULT_DATASIZE	0x0f
#define NG_IRLAP_DEFAULT_WINSIZE	0x01
#define NG_IRLAP_DEFAULT_NBOF		0x08
#define NG_IRLAP_DEFAULT_MINTURN	0x07
#define NG_IRLAP_DEFAULT_THRESH		0xff

/* Connection parameters.  Read-only. */
struct ng_irlap_conn_params {
	u_int16_t	rate;
	u_int8_t	maxturn;
	u_int8_t	datasize;
	u_int8_t	winsize;
	u_int8_t	nbof;
	u_int8_t	minturn;
	u_int8_t	thresh;
};

/* Keep this in sync with the above structure definition */
#define	NG_IRLAP_CONN_PARAMS_TYPE_INFO {			\
	{							\
	  { "rate",	&ng_parse_int16_type	},		\
	  { "maxturn",	&ng_parse_int8_type	},		\
	  { "datasize",	&ng_parse_int8_type	},		\
	  { "winsize",	&ng_parse_int8_type	},		\
	  { "nbof",	&ng_parse_int8_type	},		\
	  { "minturn",	&ng_parse_int8_type	},		\
	  { "thresh",	&ng_parse_int8_type	},		\
	  { NULL },						\
	}							\
}

struct ng_irlap_device_info {
	int		length;
	u_int8_t	data[23];
};

#define	NG_IRLAP_DEVICE_INFO_TYPE_INFO {				\
	{								\
	  { "length",		&ng_parse_int32_type		},	\
	  { "data",		&ng_irlap_device_info_data_type	},	\
	  { NULL }							\
	}								\
}

struct ng_irlap_discovery_entry {
	time_t		timestamp;
	u_int8_t	solicited;
	u_int8_t	sniff;
	u_int32_t	address;
	u_int8_t	version;
	struct		ng_irlap_device_info	info;
};

/* Keep this in sync with the above structure definition */
#define	NG_IRLAP_DISCOVERY_ENTRY_TYPE_INFO {				\
	{								\
	  { "timestamp",	&ng_parse_int32_type		},	\
	  { "solicited",	&ng_parse_int8_type		},	\
	  { "sniff",		&ng_parse_int8_type		},	\
	  { "address",		&ng_parse_int32_type		},	\
	  { "version",		&ng_parse_int8_type		},	\
	  { "info_length",	&ng_parse_int32_type		},	\
	  { "info",		&ngi_device_info_type		},	\
	  { NULL },							\
	}								\
}

/* Commands */
enum {
	NGM_IRLAP_CMD_DISCOVER = 1,	/* Perform discovery */
	NGM_IRLAP_CMD_CONNECT,		/* Connect to another device */
	NGM_IRLAP_CMD_DISCONNECT,	/* Close an open connection */
	NGM_IRLAP_CMD_RESET,		/* Reset a current connection */
	NGM_IRLAP_CMD_EXCHANGE,		/* Exchange roles in a connection */
	NGM_IRLAP_CMD_GET_CONN_PARAMS,	/* Get current connection parameters */
	NGM_IRLAP_CMD_SET_DEVICE_INFO,	/* Set device information */
	NGM_IRLAP_CMD_GET_DEVICE_INFO,	/* Get device information */
};

#endif /* _NG_IRLAP_H_ */
